@@ -1,7 +1,7 @@
 """PBX path objects"""
 
 import os
-from typing import cast, List, Optional
+from typing import cast, Optional
 
 import deserialize
 
@@ -16,11 +16,11 @@ from .pbxobject import PBXObject
 class PBXPathObject(PBXObject):
     """Represents an object with a path (i.e. file or group)."""
 
-    path: Optional[str]
+    path: str | None
     source_tree: str
 
-    _parent_group_reference: Optional[str]
-    _full_path: Optional[str]
+    _parent_group_reference: str | None
+    _relative_path: str | None
 
     def parent_group(self) -> Optional["PBXGroup"]:
         """Find the parent group of a reference.
@@ -40,24 +40,21 @@ class PBXPathObject(PBXObject):
                 self.project().objects[getattr(self, "_parent_group_reference")],
             )
 
-        for group in self.project().fetch_type(PBXGroup).values():
-            if self in group.children:
-                setattr(self, "_parent_group_reference", group.object_key)
-                return group
+        group_types_to_check: list[type] = [
+            PBXGroup,
+            PBXVariantGroup,
+            XCVersionGroup,
+        ]
 
-        for group in self.project().fetch_type(PBXVariantGroup).values():
-            if self in group.children:
-                setattr(self, "_parent_group_reference", group.object_key)
-                return group
-
-        for group in self.project().fetch_type(XCVersionGroup).values():
-            if self in group.children:
-                setattr(self, "_parent_group_reference", group.object_key)
-                return group
+        for group_type in group_types_to_check:
+            for group in self.project().fetch_type(group_type).values():
+                if self in group.children:
+                    setattr(self, "_parent_group_reference", group.object_key)
+                    return group
 
         return None
 
-    def relative_path(self) -> Optional[str]:
+    def relative_path(self) -> str | None:
         """Get the relative path for the group to the source root
 
         This works by getting the current references path, then searching up the
@@ -72,10 +69,8 @@ class PBXPathObject(PBXObject):
 
         # pylint: disable=too-many-return-statements
 
-        if hasattr(self, "_relative_path"):
-            cached_path = getattr(self, "_relative_path")
-            if cached_path is not None:
-                return cast(str, cached_path)
+        if hasattr(self, "_relative_path") and self._relative_path is not None:
+            return self._relative_path
 
         if self.source_tree == "SOURCE_ROOT":
             setattr(self, "_relative_path", self.path)
@@ -91,29 +86,79 @@ class PBXPathObject(PBXObject):
                 return self.path
             raise Exception(f"Unexpected source tree: {self.source_tree}")
 
+        # Ok, it now gets incredible hairy. Essentially, a file has either its own path, or it has
+        # a path relative to its parent. However, the parent may not have a path and be "virtual".
+        # In that case, we need to determine the grandparent's path to use as the base. This is a
+        # recursive process. Once we get to the root, we can't make any assumptions, so assume the
+        # relative path to be the empty string.
+
         parent = self.parent_group()
 
         if not parent:
-            return None
+            base_path_for_self = ""
+        else:
+            parent_folder_path = parent.relative_path()
+            if parent_folder_path is None:
+                # If there's no parent relative path, then we have no path relative to anything else
+                base_path_for_self = ""
+            elif parent.path is not None:
+                # If there is a parent path and , we use it as the base path
+                base_path_for_self = parent_folder_path
+            else:
+                # Parent is a "virtual" group (no 'path' attribute)
+                child_path_includes_virtual_parent_name = False
 
-        parent_path = parent.relative_path()
+                # Check if the child's path includes the parent's name
+                if parent.name and self.path:
+                    if self.path == parent.name or self.path.startswith(parent.name + os.sep):
+                        child_path_includes_virtual_parent_name = True
 
-        if self.path is None:
-            setattr(self, "_relative_path", parent_path)
-            return parent_path
+                # If the child's path includes the parent's name, we need to determine
+                # the base path for this child.
+                if child_path_includes_virtual_parent_name:
+                    # Child's path (e.g., "VirtualGroupName/File.swift") already includes the virtual parent's name.
+                    # So, the base path for this child is the parent's container (grandparent's folder).
+                    grandparent = parent.parent_group()
+                    if not grandparent or grandparent.relative_path() is None:
+                        # Virtual parent is main group or orphan. Either way, its container is effectively root.
+                        base_path_for_self = ""
+                    else:
+                        base_path_for_self = grandparent.relative_path()
+                else:
+                    # Parent is virtual, but child's path does not start with parent's name
+                    # (e.g., parent "Commands", child path "MyFile.swift").
+                    # So, child is inside the folder conceptually represented by the virtual parent.
+                    base_path_for_self = parent_folder_path
 
-        if parent_path is None:
-            setattr(self, "_relative_path", self.path)
-            return self.path
+        # Determine the path segment contributed by this object itself
+        if isinstance(self, PBXGroup):
+            # For a group, if it's the main group and has no path/name, it contributes nothing.
+            if (
+                self.project().project.main_group_id == self.object_key
+                and not self.path
+                and not self.name
+            ):
+                current_segment_from_self = None
+            else:
+                current_segment_from_self = self.path
+        else:  # PBXFileReference or other similar types
+            current_segment_from_self = self.path
 
-        value = os.path.join(parent_path, self.path)
-        setattr(self, "_relative_path", value)
-
-        return value
+        if current_segment_from_self is None:
+            calculated_path = base_path_for_self
+        else:
+            if base_path_for_self == "" and current_segment_from_self.startswith(os.sep):
+                # Avoid os.path.join("", "/abs/path") becoming "//abs/path"
+                calculated_path = current_segment_from_self
+            else:
+                assert base_path_for_self is not None
+                calculated_path = os.path.join(base_path_for_self, current_segment_from_self)
 
+        setattr(self, "_relative_path", calculated_path)
+        return calculated_path
         # pylint: enable=too-many-return-statements
 
-    def absolute_path(self) -> Optional[str]:
+    def absolute_path(self) -> str | None:
         """Find the absolute path
 
         :returns: The absolute path of the object
@@ -151,14 +196,14 @@ class PBXGroup(PBXPathObject):
     This is a group in the Xcode file explorer.
     """
 
-    children_ids: List[str]
-    indent_width: Optional[int]
-    tab_width: Optional[int]
-    uses_tabs: Optional[bool]
-    name: Optional[str]
+    children_ids: list[str]
+    indent_width: int | None
+    tab_width: int | None
+    uses_tabs: bool | None
+    name: str | None
 
     @property
-    def children(self) -> List[PBXPathObject]:
+    def children(self) -> list[PBXPathObject]:
         """Get all the children for this group.
 
         :returns: The children for this group
@@ -175,7 +220,7 @@ class PBXVariantGroup(PBXGroup):
     .strings file, where the "file" can be expanded to see each language.
     """
 
-    name: str
+    name: str  # type: ignore
 
 
 @deserialize.key("file_encoding", "fileEncoding")
@@ -196,16 +241,16 @@ class PBXFileReference(PBXPathObject):
     The details of a particular file.
     """
 
-    file_encoding: Optional[int]
-    last_known_file_type: Optional[str]
-    line_ending: Optional[str]
-    indent_width: Optional[str]
-    tab_width: Optional[str]
-    wraps_lines: Optional[bool]
-    name: Optional[str]
-    xc_language_specification_identifier: Optional[str]
-    explicit_file_type: Optional[str]
-    include_in_index: Optional[str]
+    file_encoding: int | None
+    last_known_file_type: str | None
+    line_ending: str | None
+    indent_width: str | None
+    tab_width: str | None
+    wraps_lines: bool | None
+    name: str | None
+    xc_language_specification_identifier: str | None
+    explicit_file_type: str | None
+    include_in_index: str | None
 
 
 @deserialize.auto_snake()
@@ -217,13 +262,13 @@ class XCVersionGroup(PBXPathObject):
     These groups have versioned files in them
     """
 
-    child_ids: List[str]
+    child_ids: list[str]
     current_version: str
     version_group_type: str
-    name: Optional[str]
+    name: str | None
 
     @property
-    def children(self) -> List[PBXPathObject]:
+    def children(self) -> list[PBXPathObject]:
         """Get all the children for this group.
 
         :returns: The children for this group
@@ -241,7 +286,7 @@ class PBXReferenceProxy(PBXPathObject):
     """
 
     file_type: str
-    path: str
+    path: str  # type: ignore
     remote_ref: str
     source_tree: str
 
@@ -258,6 +303,6 @@ class PBXFileSystemSynchronizedRootGroup(PBXPathObject):
     reduce merge conflicts in the pbxproj.
     """
 
-    exception_ids: List[str]
+    exception_ids: list[str]
     explicit_file_types: dict[str, str]
-    explicit_folders: List[str]
+    explicit_folders: list[str]
