@@ -388,6 +388,7 @@ class BuildAction(Action):
         self.build_implicit_dependencies = (
             node.attrib.pop("buildImplicitDependencies", None) == "YES"
         )
+        self.build_architectures = node.attrib.pop("buildArchitectures", None)
         self.build_action_entries = []
         assert len(node.attrib) == 0, f"Unhandled attributes: {list(node.attrib.keys())}"
 
@@ -420,6 +421,9 @@ class TestAction(Action):
         self.only_generate_coverage_for_specific_targets = (
             node.attrib.pop("onlyGenerateCoverageForSpecifiedTargets", None) == "YES"
         )
+        self.should_autocreate_test_plan = (
+            node.attrib.pop("shouldAutocreateTestPlan", None) == "YES"
+        )
         self.test_plans = []
         self.testables = []
         self.code_coverage_targets = None
