@@ -1,7 +1,7 @@
 """PBX object types"""
 
 import enum
-from typing import cast, List, Optional
+from typing import cast
 
 import deserialize
 
@@ -9,6 +9,7 @@ from .pbxobject import PBXObject
 from .buildphases import PBXBuildPhase
 from .buildrules import PBXBuildRule
 from .pathobjects import PBXFileReference
+from .other import PBXTargetDependency
 from .xcobjects import XCConfigurationList
 
 
@@ -40,13 +41,13 @@ class PBXTarget(PBXObject):
     """Represents a PBXTarget."""
 
     build_configuration_list_id: str
-    build_phases_ids: List[str]
-    dependency_ids: List[str]
+    build_phases_ids: list[str]
+    dependency_ids: list[str]
     name: str
-    product_name: Optional[str]
+    product_name: str | None
 
     @property
-    def build_phases(self) -> List[PBXBuildPhase]:
+    def build_phases(self) -> list[PBXBuildPhase]:
         """Get the build phases in the target."""
         return [cast(PBXBuildPhase, self.objects()[phase_id]) for phase_id in self.build_phases_ids]
 
@@ -56,10 +57,11 @@ class PBXTarget(PBXObject):
         return cast(XCConfigurationList, self.objects()[self.build_configuration_list_id])
 
     @property
-    def dependencies(self) -> List["PBXTarget"]:
+    def dependencies(self) -> list["PBXTargetDependency"]:
         """Get the dependencies of the target."""
         return [
-            cast(PBXTarget, self.objects()[dependency_id]) for dependency_id in self.dependency_ids
+            cast(PBXTargetDependency, self.objects()[dependency_id])
+            for dependency_id in self.dependency_ids
         ]
 
 
@@ -78,20 +80,20 @@ class PBXNativeTarget(PBXTarget):
     This is the corresponding target type to an aggregate target.
     """
 
-    build_rule_ids: Optional[List[str]]
-    product_reference_id: Optional[str]
+    build_rule_ids: list[str] | None
+    product_reference_id: str | None
     product_type: PBXProductType
-    package_product_dependencies: Optional[List[str]]
+    package_product_dependencies: list[str] | None
 
     @property
-    def product_reference(self) -> Optional[PBXFileReference]:
+    def product_reference(self) -> PBXFileReference | None:
         """Get the product reference of the target."""
         if self.product_reference_id is None:
             return None
         return cast(PBXFileReference, self.objects()[self.product_reference_id])
 
     @property
-    def build_rules(self) -> List[PBXBuildRule]:
+    def build_rules(self) -> list[PBXBuildRule]:
         """Get the product reference of the target."""
         if self.build_rule_ids is None:
             return []
